summaryrefslogtreecommitdiffstats
path: root/libkcal/tests/testfields.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'libkcal/tests/testfields.cpp')
-rw-r--r--libkcal/tests/testfields.cpp30
1 files changed, 15 insertions, 15 deletions
diff --git a/libkcal/tests/testfields.cpp b/libkcal/tests/testfields.cpp
index cc835927..6e63faa9 100644
--- a/libkcal/tests/testfields.cpp
+++ b/libkcal/tests/testfields.cpp
@@ -50,18 +50,18 @@ int main(int argc,char **argv)
Q_UNUSED(args)
- CalendarLocal cal( TQString::tqfromLatin1("UTC") );
+ CalendarLocal cal( TQString::fromLatin1("UTC") );
- TQString file = TQString::tqfromLatin1( INPUT );
+ TQString file = TQString::fromLatin1( INPUT );
if (!cal.load( file ) ) {
kdError() << "Can't load " << file << endl;
return 1;
}
- // 2 tests... first uid should result in a synctqStatus of 0. second uid
- // should have a new summary and a 1 for synctqStatus.
- TQString uid1 = TQString::tqfromLatin1("KOrganizer-1345486115.965");
- TQString uid2 = TQString::tqfromLatin1("KOrganizer-1345486115.967");
+ // 2 tests... first uid should result in a syncStatus of 0. second uid
+ // should have a new summary and a 1 for syncStatus.
+ TQString uid1 = TQString::fromLatin1("KOrganizer-1345486115.965");
+ TQString uid2 = TQString::fromLatin1("KOrganizer-1345486115.967");
Event *e = cal.event( uid1 );
if (!e) {
@@ -78,7 +78,7 @@ int main(int argc,char **argv)
if (e->pilotId()) {
kdDebug() << "Pilot ID = " << e->pilotId() << endl;
- kdDebug() << "Pilot Sync Status = " << e->synctqStatus() << endl;
+ kdDebug() << "Pilot Sync Status = " << e->syncStatus() << endl;
} else {
kdError() << "No Pilot ID" << endl;
return 1;
@@ -86,9 +86,9 @@ int main(int argc,char **argv)
kdDebug() << "First test passed. Able to read fields." << endl;
- e->setSynctqStatus(KCal::Incidence::SYNCNONE);
+ e->setSyncStatus(KCal::Incidence::SYNCNONE);
- TQString newSummary = TQString::tqfromLatin1("Mooo summary");
+ TQString newSummary = TQString::fromLatin1("Mooo summary");
Event *f = new Event(*e);
@@ -112,7 +112,7 @@ int main(int argc,char **argv)
// now try to read the file back in and see if our changes made it
- CalendarLocal cal2( TQString::tqfromLatin1("UTC") );
+ CalendarLocal cal2( TQString::fromLatin1("UTC") );
if (!cal2.load( filew ) ) {
kdError() << "Can't load " << filew << endl;
return 1;
@@ -120,7 +120,7 @@ int main(int argc,char **argv)
TQFile::remove( filew );
// check for uid1--should have synctqStatus of 0
e = cal2.event( uid1 );
if (!e) {
kdError() << "No event for first read test" << uid1 << endl;
@@ -131,13 +131,13 @@ int main(int argc,char **argv)
if (e->pilotId()) {
kdDebug() << "First Pilot ID = " << e->pilotId() << endl;
- kdDebug() << "First Pilot Sync Status = " << e->synctqStatus() << endl;
+ kdDebug() << "First Pilot Sync Status = " << e->syncStatus() << endl;
} else {
kdError() << "No Pilot ID for first test" << endl;
return 1;
}
- if (e->synctqStatus() != KCal::Incidence::SYNCNONE) {
+ if (e->syncStatus() != KCal::Incidence::SYNCNONE) {
kdError() << "Wrong Pilot sync status." << endl;
return 1;
}
@@ -154,13 +154,13 @@ int main(int argc,char **argv)
if (f->pilotId()) {
kdDebug() << "Second Pilot ID = " << f->pilotId() << endl;
- kdDebug() << "Second Pilot Sync Status = " << f->synctqStatus() << endl;
+ kdDebug() << "Second Pilot Sync Status = " << f->syncStatus() << endl;
} else {
kdError() << "No Pilot ID for second read test" << endl;
return 1;
}
- if (f->synctqStatus() != KCal::Incidence::SYNCMOD) {
+ if (f->syncStatus() != KCal::Incidence::SYNCMOD) {
kdError() << "Wrong Pilot sync status for second read test." << endl;
return 1;
}
@@ -120,7 +120,7 @@ int main(int argc,char **argv)
TQFile::remove( filew );
- // check for uid1--should have synctqStatus of 0
+ // check for uid1--should have syncStatus of 0
e = cal2.event( uid1 );
if (!e) {